@@ -35,24 +35,33 @@ class ConfigController extends Controller
     public function createApplicationTabs()
     {
         $tabs = $this->getTabs();
-        $tabs->add('general', array(
-            'title' => $this->translate('Adjust the general configuration of Icinga Web 2'),
-            'label' => $this->translate('General'),
-            'url'   => 'config/general',
-            'baseTarget' => '_main'
-        ));
-        $tabs->add('resource', array(
-            'title' => $this->translate('Configure which resources are being utilized by Icinga Web 2'),
-            'label' => $this->translate('Resources'),
-            'url'   => 'config/resource',
-            'baseTarget' => '_main'
-        ));
-        $tabs->add('authentication', array(
-            'title' => $this->translate('Configure the user and group backends'),
-            'label' => $this->translate('Authentication'),
-            'url'   => 'config/userbackend',
-            'baseTarget' => '_main'
-        ));
+        if ($this->hasPermission('config/general')) {
+            $tabs->add('general', array(
+                'title' => $this->translate('Adjust the general configuration of Icinga Web 2'),
+                'label' => $this->translate('General'),
+                'url'   => 'config/general',
+                'baseTarget' => '_main'
+            ));
+        }
+        if ($this->hasPermission('config/resources')) {
+            $tabs->add('resource', array(
+                'title' => $this->translate('Configure which resources are being utilized by Icinga Web 2'),
+                'label' => $this->translate('Resources'),
+                'url'   => 'config/resource',
+                'baseTarget' => '_main'
+            ));
+        }
+        if ($this->hasPermission('config/access-control/users')
+            || $this->hasPermission('config/access-control/groups')
+        ) {
+            $tabs->add('authentication', array(
+                'title' => $this->translate('Configure the user and group backends'),
+                'label' => $this->translate('Access Control Backends'),
+                'url'   => 'config/userbackend',
+                'baseTarget' => '_main'
+            ));
+        }
+
         return $tabs;
     }
 
@@ -66,7 +75,15 @@ class ConfigController extends Controller
      */
     public function indexAction()
     {
-        $this->redirectNow('config/general');
+        if ($this->hasPermission('config/general')) {
+            $this->redirectNow('config/general');
+        } elseif ($this->hasPermission('config/resources')) {
+            $this->redirectNow('config/resource');
+        } elseif ($this->hasPermission('config/access-control/*')) {
+            $this->redirectNow('config/userbackend');
+        } else {
+            throw new SecurityException('No permission to configure Icinga Web 2');
+        }
     }
 
     /**
@@ -76,12 +93,13 @@ class ConfigController extends Controller
      */
     public function generalAction()
     {
-        $this->assertPermission('config/application/general');
+        $this->assertPermission('config/general');
         $form = new GeneralConfigForm();
         $form->setIniConfig(Config::app());
         $form->handleRequest();
 
         $this->view->form = $form;
+        $this->view->title = $this->translate('General');
         $this->createApplicationTabs()->activate('general');
     }
 
@@ -107,6 +125,7 @@ class ConfigController extends Controller
             ->order('name');
         $this->setupLimitControl();
         $this->setupPaginationControl($this->view->modules);
+        $this->view->title = $this->translate('Modules');
     }
 
     public function moduleAction()
@@ -136,7 +155,10 @@ class ConfigController extends Controller
             }
 
             $this->view->module = $module;
+            $this->view->libraries = $app->getLibraries();
+            $this->view->moduleManager = $manager;
             $this->view->toggleForm = $toggleForm;
+            $this->view->title = $module->getName();
             $this->view->tabs = $module->getConfigTabs()->activate('info');
             $this->view->moduleGitCommitId = Version::getGitHead($module->getBaseDir());
         } else {
@@ -154,17 +176,31 @@ class ConfigController extends Controller
 
         $form = new ActionForm();
         $form->setOnSuccess(function (ActionForm $form) {
-            $module = $form->getValue('identifier');
-            Icinga::app()->getModuleManager()->enableModule($module);
-            Notification::success(sprintf($this->translate('Module "%s" enabled'), $module));
-            $this->rerenderLayout()->reloadCss()->redirectNow('config/modules');
+            $moduleName = $form->getValue('identifier');
+            $module = Icinga::app()->getModuleManager()
+                ->enableModule($moduleName)
+                ->getModule($moduleName);
+            Notification::success(sprintf($this->translate('Module "%s" enabled'), $moduleName));
+            $form->onSuccess();
+
+            if ($module->hasJs()) {
+                $this->getResponse()
+                    ->setReloadWindow(true)
+                    ->sendResponse();
+            } else {
+                if ($module->hasCss()) {
+                    $this->reloadCss();
+                }
+
+                $this->rerenderLayout()->redirectNow('config/modules');
+            }
         });
 
         try {
             $form->handleRequest();
         } catch (Exception $e) {
             $this->view->exceptionMessage = $e->getMessage();
-            $this->view->moduleName = $form->getValue('name');
+            $this->view->moduleName = $form->getValue('identifier');
             $this->view->action = 'enable';
             $this->render('module-configuration-error');
         }
@@ -179,17 +215,31 @@ class ConfigController extends Controller
 
         $form = new ActionForm();
         $form->setOnSuccess(function (ActionForm $form) {
-            $module = $form->getValue('identifier');
-            Icinga::app()->getModuleManager()->disableModule($module);
-            Notification::success(sprintf($this->translate('Module "%s" disabled'), $module));
-            $this->rerenderLayout()->reloadCss()->redirectNow('config/modules');
+            $mm = Icinga::app()->getModuleManager();
+            $moduleName = $form->getValue('identifier');
+            $module = $mm->getModule($moduleName);
+            $mm->disableModule($moduleName);
+            Notification::success(sprintf($this->translate('Module "%s" disabled'), $moduleName));
+            $form->onSuccess();
+
+            if ($module->hasJs()) {
+                $this->getResponse()
+                    ->setReloadWindow(true)
+                    ->sendResponse();
+            } else {
+                if ($module->hasCss()) {
+                    $this->reloadCss();
+                }
+
+                $this->rerenderLayout()->redirectNow('config/modules');
+            }
         });
 
         try {
             $form->handleRequest();
         } catch (Exception $e) {
             $this->view->exceptionMessage = $e->getMessage();
-            $this->view->moduleName = $form->getValue('name');
+            $this->view->moduleName = $form->getValue('identifier');
             $this->view->action = 'disable';
             $this->render('module-configuration-error');
         }
@@ -200,15 +250,19 @@ class ConfigController extends Controller
      */
     public function userbackendAction()
     {
-        $this->assertPermission('config/application/userbackend');
-        $this->assertPermission('config/application/usergroupbackend');
-        $form = new UserBackendReorderForm();
-        $form->setIniConfig(Config::app('authentication'));
-        $form->handleRequest();
+        if ($this->hasPermission('config/access-control/users')) {
+            $form = new UserBackendReorderForm();
+            $form->setIniConfig(Config::app('authentication'));
+            $form->handleRequest();
+            $this->view->form = $form;
+        }
+
+        if ($this->hasPermission('config/access-control/groups')) {
+            $this->view->backendNames = Config::app('groups');
+        }
 
-        $this->view->form = $form;
-        $this->view->backendNames = Config::app('groups');
         $this->createApplicationTabs()->activate('authentication');
+        $this->view->title = $this->translate('Authentication');
         $this->render('userbackend/reorder');
     }
 
@@ -217,7 +271,7 @@ class ConfigController extends Controller
      */
     public function createuserbackendAction()
     {
-        $this->assertPermission('config/application/userbackend');
+        $this->assertPermission('config/access-control/users');
         $form = new UserBackendConfigForm();
         $form
             ->setRedirectUrl('config/userbackend')
@@ -230,7 +284,7 @@ class ConfigController extends Controller
         try {
             $form->setResourceConfig(ResourceFactory::getResourceConfigs());
         } catch (ConfigurationError $e) {
-            if ($this->hasPermission('config/application/resources')) {
+            if ($this->hasPermission('config/resources')) {
                 Notification::error($e->getMessage());
                 $this->redirectNow('config/createresource');
             }
@@ -255,6 +309,7 @@ class ConfigController extends Controller
         });
         $form->handleRequest();
 
+        $this->view->title = $this->translate('Authentication');
         $this->renderForm($form, $this->translate('New User Backend'));
     }
 
@@ -263,7 +318,7 @@ class ConfigController extends Controller
      */
     public function edituserbackendAction()
     {
-        $this->assertPermission('config/application/userbackend');
+        $this->assertPermission('config/access-control/users');
         $backendName = $this->params->getRequired('backend');
 
         $form = new UserBackendConfigForm();
@@ -293,6 +348,7 @@ class ConfigController extends Controller
             $this->httpNotFound(sprintf($this->translate('User backend "%s" not found'), $backendName));
         }
 
+        $this->view->title = $this->translate('Authentication');
         $this->renderForm($form, $this->translate('Update User Backend'));
     }
 
@@ -301,7 +357,7 @@ class ConfigController extends Controller
      */
     public function removeuserbackendAction()
     {
-        $this->assertPermission('config/application/userbackend');
+        $this->assertPermission('config/access-control/users');
         $backendName = $this->params->getRequired('backend');
 
         $backendForm = new UserBackendConfigForm();
@@ -325,6 +381,7 @@ class ConfigController extends Controller
         });
         $form->handleRequest();
 
+        $this->view->title = $this->translate('Authentication');
         $this->renderForm($form, $this->translate('Remove User Backend'));
     }
 
@@ -333,11 +390,12 @@ class ConfigController extends Controller
      */
     public function resourceAction()
     {
-        $this->assertPermission('config/application/resources');
+        $this->assertPermission('config/resources');
         $this->view->resources = Config::app('resources', true)->getConfigObject()
             ->setKeyColumn('name')
             ->select()
             ->order('name');
+        $this->view->title = $this->translate('Resources');
         $this->createApplicationTabs()->activate('resource');
     }
 
@@ -346,7 +404,7 @@ class ConfigController extends Controller
      */
     public function createresourceAction()
     {
-        $this->assertPermission('config/application/resources');
+        $this->assertPermission('config/resources');
         $this->getTabs()->add('resources/new', array(
             'label' => $this->translate('New Resource'),
             'url'   => Url::fromRequest()
@@ -358,6 +416,7 @@ class ConfigController extends Controller
         $form->handleRequest();
 
         $this->view->form = $form;
+        $this->view->title = $this->translate('Resources');
         $this->render('resource/create');
     }
 
@@ -366,7 +425,7 @@ class ConfigController extends Controller
      */
     public function editresourceAction()
     {
-        $this->assertPermission('config/application/resources');
+        $this->assertPermission('config/resources');
         $this->getTabs()->add('resources/update', array(
             'label' => $this->translate('Update Resource'),
             'url'   => Url::fromRequest()
@@ -377,6 +436,7 @@ class ConfigController extends Controller
         $form->handleRequest();
 
         $this->view->form = $form;
+        $this->view->title = $this->translate('Resources');
         $this->render('resource/modify');
     }
 
@@ -385,7 +445,7 @@ class ConfigController extends Controller
      */
     public function removeresourceAction()
     {
-        $this->assertPermission('config/application/resources');
+        $this->assertPermission('config/resources');
         $this->getTabs()->add('resources/remove', array(
             'label' => $this->translate('Remove Resource'),
             'url'   => Url::fromRequest()
@@ -441,6 +501,7 @@ class ConfigController extends Controller
         }
 
         $this->view->form = $form;
+        $this->view->title = $this->translate('Resources');
         $this->render('resource/remove');
     }
 }
