@@ -33,7 +33,6 @@ class ApplicationConfigForm extends Form
             'checkbox',
             'global_show_stacktraces',
             array(
-                'required'      => true,
                 'value'         => true,
                 'label'         => $this->translate('Show Stacktraces'),
                 'description'   => $this->translate(
@@ -43,6 +42,19 @@ class ApplicationConfigForm extends Form
             )
         );
 
+        $this->addElement(
+            'checkbox',
+            'global_show_application_state_messages',
+            array(
+                'value'         => true,
+                'label'         => $this->translate('Show Application State Messages'),
+                'description'   => $this->translate(
+                    "Set whether to show application state messages."
+                    . " This can also be set in a user's preferences."
+                )
+            )
+        );
+
         $this->addElement(
             'text',
             'global_module_path',
@@ -58,40 +70,24 @@ class ApplicationConfigForm extends Form
             )
         );
 
+        $backends = array_keys(ResourceFactory::getResourceConfigs()->toArray());
+        $backends = array_combine($backends, $backends);
+
         $this->addElement(
             'select',
-            'global_config_backend',
+            'global_config_resource',
             array(
                 'required'      => true,
-                'autosubmit'    => true,
-                'label'         => $this->translate('User Preference Storage Type'),
-                'multiOptions'  => array(
-                    'ini'   => $this->translate('File System (INI Files)'),
-                    'db'    => $this->translate('Database'),
-                    'none'  => $this->translate('Don\'t Store Preferences')
-                )
+                'multiOptions'  => array_merge(
+                    ['' => sprintf(' - %s - ', $this->translate('Please choose'))],
+                    $backends
+                ),
+                'disable'       => [''],
+                'value'         => '',
+                'label'         => $this->translate('Configuration Database')
             )
         );
 
-        if (isset($formData['global_config_backend']) && $formData['global_config_backend'] === 'db') {
-            $backends = array();
-            foreach (ResourceFactory::getResourceConfigs()->toArray() as $name => $resource) {
-                if ($resource['type'] === 'db') {
-                    $backends[$name] = $name;
-                }
-            }
-
-            $this->addElement(
-                'select',
-                'global_config_resource',
-                array(
-                    'required'      => true,
-                    'multiOptions'  => $backends,
-                    'label'         => $this->translate('Database Connection')
-                )
-            );
-        }
-
         return $this;
     }
 }
