@@ -3,18 +3,23 @@
 
 namespace Icinga\Authentication\UserGroup;
 
+use Exception;
 use Icinga\Authentication\User\UserBackend;
 use Icinga\Authentication\User\LdapUserBackend;
 use Icinga\Application\Logger;
 use Icinga\Data\ConfigObject;
+use Icinga\Data\Inspectable;
+use Icinga\Data\Inspection;
+use Icinga\Exception\AuthenticationException;
 use Icinga\Exception\ConfigurationError;
 use Icinga\Exception\ProgrammingError;
 use Icinga\Protocol\Ldap\LdapException;
+use Icinga\Protocol\Ldap\LdapUtils;
 use Icinga\Repository\LdapRepository;
 use Icinga\Repository\RepositoryQuery;
 use Icinga\User;
 
-class LdapUserGroupBackend extends LdapRepository implements UserGroupBackendInterface
+class LdapUserGroupBackend extends LdapRepository implements Inspectable, UserGroupBackendInterface
 {
     /**
      * The user backend being associated with this user group backend
@@ -100,6 +105,13 @@ class LdapUserGroupBackend extends LdapRepository implements UserGroupBackendInt
      */
     protected $nestedGroupSearch;
 
+    /**
+     * The domain the backend is responsible for
+     *
+     * @var string
+     */
+    protected $domain;
+
     /**
      * The columns which are not permitted to be queried
      *
@@ -157,7 +169,7 @@ class LdapUserGroupBackend extends LdapRepository implements UserGroupBackendInt
      */
     public function setUserBaseDn($baseDn)
     {
-        if (($baseDn = trim($baseDn))) {
+        if ($baseDn && ($baseDn = trim($baseDn))) {
             $this->userBaseDn = $baseDn;
         }
 
@@ -183,7 +195,7 @@ class LdapUserGroupBackend extends LdapRepository implements UserGroupBackendInt
      */
     public function setGroupBaseDn($baseDn)
     {
-        if (($baseDn = trim($baseDn))) {
+        if ($baseDn && ($baseDn = trim($baseDn))) {
             $this->groupBaseDn = $baseDn;
         }
 
@@ -324,7 +336,7 @@ class LdapUserGroupBackend extends LdapRepository implements UserGroupBackendInt
      */
     public function setUserFilter($filter)
     {
-        if (($filter = trim($filter))) {
+        if ($filter && ($filter = trim($filter))) {
             if ($filter[0] === '(') {
                 $filter = substr($filter, 1, -1);
             }
@@ -354,7 +366,7 @@ class LdapUserGroupBackend extends LdapRepository implements UserGroupBackendInt
      */
     public function setGroupFilter($filter)
     {
-        if (($filter = trim($filter))) {
+        if ($filter && ($filter = trim($filter))) {
             $this->groupFilter = $filter;
         }
 
@@ -394,9 +406,46 @@ class LdapUserGroupBackend extends LdapRepository implements UserGroupBackendInt
         return $this->nestedGroupSearch;
     }
 
+    /**
+     * Get the domain the backend is responsible for
+     *
+     * If the LDAP group backend is linked with a LDAP user backend,
+     * the domain of the user backend will be returned.
+     *
+     * @return string
+     */
+    public function getDomain()
+    {
+        return $this->userBackend !== null ? $this->userBackend->getDomain() : $this->domain;
+    }
+
+    /**
+     * Set the domain the backend is responsible for
+     *
+     * If the LDAP group backend is linked with a LDAP user backend,
+     * the domain of the user backend will be used nonetheless.
+     *
+     * @param   string  $domain
+     *
+     * @return  $this
+     */
+    public function setDomain($domain)
+    {
+        if ($domain && ($domain = trim($domain))) {
+            $this->domain = $domain;
+        }
+
+        return $this;
+    }
+
     /**
      * Return whether the attribute name where to find a group's member holds ambiguous values
      *
+     * This tries to detect if the member attribute of groups contain:
+     *
+     *  full DN -> distinguished name of another object
+     *  other   -> ambiguous field referencing the member by userNameAttribute
+     *
      * @return  bool
      *
      * @throws  ProgrammingError    In case either $this->groupClass or $this->groupMemberAttribute
@@ -415,14 +464,41 @@ class LdapUserGroupBackend extends LdapRepository implements UserGroupBackendInt
                 );
             }
 
-            $sampleValue = $this->ds
+            $sampleValues = $this->ds
                 ->select()
                 ->from($this->groupClass, array($this->groupMemberAttribute))
                 ->where($this->groupMemberAttribute, '*')
+                ->limit(Logger::getInstance()->getLevel() === Logger::DEBUG ? 3 : 1)
                 ->setUnfoldAttribute($this->groupMemberAttribute)
                 ->setBase($this->groupBaseDn)
-                ->fetchOne();
-            $this->ambiguousMemberAttribute = !$this->isRelatedDn($sampleValue);
+                ->fetchAll();
+
+            Logger::debug('Ambiguity query returned %d results', count($sampleValues));
+
+            $i = 0;
+            $sampleValue = null;
+            foreach ($sampleValues as $key => $value) {
+                if ($sampleValue === null) {
+                    $sampleValue = $value;
+                }
+
+                Logger::debug('Result %d: %s (%s)', ++$i, $value, $key);
+            }
+
+            if (is_object($sampleValue) && isset($sampleValue->{$this->groupMemberAttribute})) {
+                $this->ambiguousMemberAttribute = ! LdapUtils::isDn($sampleValue->{$this->groupMemberAttribute});
+
+                Logger::debug(
+                    'Ambiguity check came to the conclusion that the member attribute %s ambiguous. Tested sample: %s',
+                    $this->ambiguousMemberAttribute ? 'is' : 'is not',
+                    $sampleValue->{$this->groupMemberAttribute}
+                );
+            } else {
+                Logger::warning(
+                    'Ambiguity query returned zero or invalid results. Sample value is `%s`',
+                    print_r($sampleValue, true)
+                );
+            }
         }
 
         return $this->ambiguousMemberAttribute;
@@ -576,6 +652,7 @@ class LdapUserGroupBackend extends LdapRepository implements UserGroupBackendInt
         return $this->ds
             ->select()
             ->from('*', array($this->userNameAttribute))
+            ->setUnfoldAttribute($this->userNameAttribute)
             ->setBase($dn)
             ->fetchOne();
     }
@@ -616,8 +693,8 @@ class LdapUserGroupBackend extends LdapRepository implements UserGroupBackendInt
     public function requireQueryColumn($table, $name, RepositoryQuery $query = null)
     {
         $column = parent::requireQueryColumn($table, $name, $query);
-        if ($name === 'user_name' && $query !== null) {
-            $query->getQuery()->setUnfoldAttribute('user_name');
+        if (($name === 'user_name' || $name === 'group_name') && $query !== null) {
+            $query->getQuery()->setUnfoldAttribute($name);
         }
 
         return $column;
@@ -632,13 +709,25 @@ class LdapUserGroupBackend extends LdapRepository implements UserGroupBackendInt
      */
     public function getMemberships(User $user)
     {
+        $domain = $this->getDomain();
+
+        if ($domain !== null) {
+            if (! $user->hasDomain() || strtolower($user->getDomain()) !== strtolower($domain)) {
+                return array();
+            }
+
+            $username = $user->getLocalUsername();
+        } else {
+            $username = $user->getUsername();
+        }
+
         if ($this->isMemberAttributeAmbiguous()) {
-            $queryValue = $user->getUsername();
+            $queryValue = $username;
         } elseif (($queryValue = $user->getAdditional('ldap_dn')) === null) {
             $userQuery = $this->ds
                 ->select()
                 ->from($this->userClass)
-                ->where($this->userNameAttribute, $user->getUsername())
+                ->where($this->userNameAttribute, $username)
                 ->setBase($this->userBaseDn)
                 ->setUsePagedResults(false);
             if ($this->userFilter) {
@@ -659,6 +748,7 @@ class LdapUserGroupBackend extends LdapRepository implements UserGroupBackendInt
         $groupQuery = $this->ds
             ->select()
             ->from($this->groupClass, array($this->groupNameAttribute))
+            ->setUnfoldAttribute($this->groupNameAttribute)
             ->where($groupMemberAttribute, $queryValue)
             ->setBase($this->groupBaseDn);
         if ($this->groupFilter) {
@@ -668,6 +758,9 @@ class LdapUserGroupBackend extends LdapRepository implements UserGroupBackendInt
         $groups = array();
         foreach ($groupQuery as $row) {
             $groups[] = $row->{$this->groupNameAttribute};
+            if ($domain !== null) {
+                $groups[] = $row->{$this->groupNameAttribute} . "@$domain";
+            }
         }
 
         return $groups;
@@ -713,8 +806,7 @@ class LdapUserGroupBackend extends LdapRepository implements UserGroupBackendInt
                 throw new ConfigurationError('User backend "%s" is not of type LDAP', $config->user_backend);
             }
 
-            if (
-                $this->ds->getHostname() !== $userBackend->getDataSource()->getHostname()
+            if ($this->ds->getHostname() !== $userBackend->getDataSource()->getHostname()
                 || $this->ds->getPort() !== $userBackend->getDataSource()->getPort()
             ) {
                 // TODO(jom): Elaborate whether it makes sense to link directories on different hosts
@@ -729,7 +821,8 @@ class LdapUserGroupBackend extends LdapRepository implements UserGroupBackendInt
                 'user_base_dn'          => $userBackend->getBaseDn(),
                 'user_class'            => $userBackend->getUserClass(),
                 'user_name_attribute'   => $userBackend->getUserNameAttribute(),
-                'user_filter'           => $userBackend->getFilter()
+                'user_filter'           => $userBackend->getFilter(),
+                'domain'                => $userBackend->getDomain()
             ));
         }
 
@@ -743,7 +836,8 @@ class LdapUserGroupBackend extends LdapRepository implements UserGroupBackendInt
             ->setGroupMemberAttribute($config->get('group_member_attribute', $defaults->group_member_attribute))
             ->setGroupFilter($config->group_filter)
             ->setUserFilter($config->user_filter)
-            ->setNestedGroupSearch((bool) $config->get('nested_group_search', $defaults->nested_group_search));
+            ->setNestedGroupSearch((bool) $config->get('nested_group_search', $defaults->nested_group_search))
+            ->setDomain($defaults->get('domain', $config->domain));
     }
 
     /**
@@ -779,4 +873,72 @@ class LdapUserGroupBackend extends LdapRepository implements UserGroupBackendInt
             'nested_group_search'       => '0'
         ));
     }
+
+    /**
+     * Inspect if this LDAP User Group Backend is working as expected by probing the backend
+     *
+     * Try to bind to the backend and fetch a single group to check if:
+     * <ul>
+     *  <li>Connection credentials are correct and the bind is possible</li>
+     *  <li>At least one group exists</li>
+     *  <li>The specified groupClass has the property specified by groupNameAttribute</li>
+     * </ul>
+     *
+     * @return  Inspection  Inspection result
+     */
+    public function inspect()
+    {
+        $result = new Inspection('Ldap User Group Backend');
+
+        // inspect the used connection to get more diagnostic info in case the connection is not working
+        $result->write($this->ds->inspect());
+
+        try {
+            try {
+                $groupQuery = $this->ds
+                    ->select()
+                    ->from($this->groupClass, array($this->groupNameAttribute))
+                    ->setBase($this->groupBaseDn);
+
+                if ($this->groupFilter) {
+                    $groupQuery->setNativeFilter($this->groupFilter);
+                }
+
+                $res = $groupQuery->fetchRow();
+            } catch (LdapException $e) {
+                throw new AuthenticationException('Connection not possible', $e);
+            }
+
+            $result->write('Searching for: ' . sprintf(
+                'objectClass "%s" in DN "%s" (Filter: %s)',
+                $this->groupClass,
+                $this->groupBaseDn ?: $this->ds->getDn(),
+                $this->groupFilter ?: 'None'
+            ));
+
+            if ($res === false) {
+                throw new AuthenticationException('Error, no groups found in backend');
+            }
+
+            $result->write(sprintf('%d groups found in backend', $groupQuery->count()));
+
+            if (! isset($res->{$this->groupNameAttribute})) {
+                throw new AuthenticationException(
+                    'GroupNameAttribute "%s" not existing in objectClass "%s"',
+                    $this->groupNameAttribute,
+                    $this->groupClass
+                );
+            }
+        } catch (AuthenticationException $e) {
+            if (($previous = $e->getPrevious()) !== null) {
+                $result->error($previous->getMessage());
+            } else {
+                $result->error($e->getMessage());
+            }
+        } catch (Exception $e) {
+            $result->error(sprintf('Unable to validate backend: %s', $e->getMessage()));
+        }
+
+        return $result;
+    }
 }
