@@ -167,7 +167,7 @@ class UserGroupBackend
 
         $resourceConfig = ResourceFactory::getResourceConfig($backendConfig->resource);
         if ($backendType === 'db' && $resourceConfig->db === 'mysql') {
-            $resourceConfig->charset = 'utf8';
+            $resourceConfig->charset = 'utf8mb4';
         }
 
         $resource = ResourceFactory::createResource($resourceConfig);
