@@ -31,7 +31,7 @@ class ServicenotificationQuery extends IdoQuery
         'history' => array(
             'output'    => null,
             'state'     => 'sn.state',
-            'timestamp' => 'sn.start_time',
+            'timestamp' => 'UNIX_TIMESTAMP(sn.start_time)',
             'type'      => '
                 CASE sn.notification_reason
                     WHEN 1 THEN \'notification_ack\'
@@ -63,7 +63,7 @@ class ServicenotificationQuery extends IdoQuery
             'notification_output'       => 'sn.output',
             'notification_reason'       => 'sn.notification_reason',
             'notification_state'        => 'sn.state',
-            'notification_timestamp'    => 'sn.start_time',
+            'notification_timestamp'    => 'UNIX_TIMESTAMP(sn.start_time)',
             'object_type'               => '(\'service\')',
             'service'                   => 'so.name2 COLLATE latin1_general_ci',
             'service_description'       => 'so.name2',
@@ -81,24 +81,24 @@ class ServicenotificationQuery extends IdoQuery
 
     protected function requireFilterColumns(Filter $filter)
     {
-        if ($filter instanceof FilterExpression && $filter->getColumn() === 'output') {
-            $this->requireColumn($filter->getColumn());
-            $filter->setColumn('sn.output');
-            return null;
+        if ($filter instanceof FilterExpression) {
+            switch ($filter->getColumn()) {
+                case 'output':
+                    $this->requireColumn('output');
+                    $filter->setColumn('sn.output');
+                    return null;
+                case 'timestamp':
+                case 'notification_timestamp':
+                    $this->requireColumn($filter->getColumn());
+                    $filter->setColumn('sn.start_time');
+                    $filter->setExpression($this->timestampForSql($this->valueToTimestamp($filter->getExpression())));
+                    return null;
+            }
         }
 
         return parent::requireFilterColumns($filter);
     }
 
-    public function isTimestamp($field)
-    {
-        if (! parent::isTimestamp($field)) {
-            return $field === 'sn.start_time';
-        }
-
-        return true;
-    }
-
     /**
      * {@inheritdoc}
      */
