@@ -3,6 +3,7 @@
 
 namespace Icinga\Module\Monitoring\Object;
 
+use Icinga\Data\Filter\FilterEqual;
 use InvalidArgumentException;
 use Icinga\Module\Monitoring\Backend\MonitoringBackend;
 
@@ -135,6 +136,7 @@ class Service extends MonitoredObject
             'service_attempt',
             'service_check_command',
             'service_check_execution_time',
+            'service_check_interval',
             'service_check_latency',
             'service_check_source',
             'service_check_timeperiod',
@@ -170,8 +172,8 @@ class Service extends MonitoredObject
             'service_state',
             'service_state_type'
         ))
-            ->where('host_name', $this->host->getName())
-            ->where('service_description', $this->service);
+            ->whereEx(new FilterEqual('host_name', '=', $this->host->getName()))
+            ->whereEx(new FilterEqual('service_description', '=', $this->service));
     }
 
     /**
