@@ -566,29 +566,14 @@ class WebWizard extends Wizard implements SetupWizard
     public function getRequirements($skipModules = false)
     {
         $set = new RequirementSet();
-        $phpVersion = Platform::getPhpVersion();
 
-        if (version_compare($phpVersion, '5.6', '>=')
-            && version_compare($phpVersion, '7.3', '<')
-        ) {
-            $set->add(new PhpVersionRequirement(array(
-                'optional'      => true,
-                'condition'     => array('>=', '7.3'),
-                'description'   => mt(
-                    'setup',
-                    'Running Icinga Web 2 requires PHP version 7.3.'
-                    . ' Older versions are only supported up until version 2.11.'
-                )
-            )));
-        } else {
-            $set->add(new PhpVersionRequirement(array(
-                'condition'     => array('>=', '7.3'),
-                'description'   => mt(
-                    'setup',
-                    'Running Icinga Web 2 requires PHP version 7.3.'
-                )
-            )));
-        }
+        $set->add(new PhpVersionRequirement(array(
+            'condition'     => array('>=', '7.2'),
+            'description'   => sprintf(mt(
+                'setup',
+                'Running Icinga Web 2 requires PHP version %s.'
+            ), '7.2')
+        )));
 
         $set->add(new OSRequirement(array(
             'optional'      => true,
@@ -601,7 +586,7 @@ class WebWizard extends Wizard implements SetupWizard
         )));
 
         $set->add(new WebLibraryRequirement(array(
-            'condition'     => ['icinga-php-library', '>=', '0.8.0'],
+            'condition'     => ['icinga-php-library', '>=', '0.9.0'],
             'alias'         => 'Icinga PHP library',
             'description'   => mt(
                 'setup',
@@ -610,7 +595,7 @@ class WebWizard extends Wizard implements SetupWizard
         )));
 
         $set->add(new WebLibraryRequirement(array(
-            'condition'     => ['icinga-php-thirdparty', '>=', '0.10.0'],
+            'condition'     => ['icinga-php-thirdparty', '>=', '0.11.0'],
             'alias'         => 'Icinga PHP Thirdparty',
             'description'   => mt(
                 'setup',
