@@ -118,6 +118,7 @@
                         )
                     ).on('load', function() {
                         $oldLink.remove();
+                        $('head').trigger('css-reloaded');
                     });
 
                     $newLink.appendTo($('head'));
@@ -211,6 +212,16 @@
             this.icinga.behaviors.navigation.trySetActiveAndSelectedByUrl($('#col1').data('icingaUrl'));
         },
 
+        moveToRight: function () {
+            let col1 = document.getElementById('col1'),
+                col2 = document.getElementById('col2'),
+                col1Backup = this.cutContainer($(col1));
+
+            this.cutContainer($(col2)); // Clear col2 states
+            this.pasteContainer($(col2), col1Backup);
+            this.layout2col();
+        },
+
         cutContainer: function ($col) {
             var props = {
               'elements': $('#' + $col.attr('id') + ' > *').detach(),
@@ -220,7 +231,7 @@
                 'data-icinga-refresh': $col.data('icingaRefresh'),
                 'data-last-update': $col.data('lastUpdate'),
                 'data-icinga-module': $col.data('icingaModule'),
-                'data-icinga-container-id': $col.data('icingaContainerId')
+                'data-icinga-container-id': $col[0].dataset.icingaContainerId
               },
               'class': $col.attr('class')
             };
@@ -230,7 +241,7 @@
             $col.removeData('icingaRefresh');
             $col.removeData('lastUpdate');
             $col.removeData('icingaModule');
-            $col.removeData('icingaContainerId');
+            delete $col[0].dataset.icingaContainerId;
             $col.removeAttr('class').attr('class', 'container');
             return props;
         },
@@ -243,7 +254,7 @@
             $col.data('icingaRefresh', backup['data']['data-icinga-refresh']);
             $col.data('lastUpdate', backup['data']['data-last-update']);
             $col.data('icingaModule', backup['data']['data-icinga-module']);
-            $col.data('icingaContainerId', backup['data']['data-icinga-container-id']);
+            $col[0].dataset.icingaContainerId = backup['data']['data-icinga-container-id'];
         },
 
         triggerWindowResize: function () {
@@ -290,7 +301,7 @@
                     this.currentLayout = matched[1];
                     if (this.currentLayout === 'poor' || this.currentLayout === 'minimal') {
                         this.layout1col();
-                    } else {
+                    } else if (this.icinga.initialized) {
                         // layout1col() also triggers this, that's why an else is required
                         $('#layout').trigger('layout-change');
                     }
@@ -318,7 +329,11 @@
             this.icinga.logger.debug('Switching to single col');
             $('#layout').removeClass('twocols');
             this.closeContainer($('#col2'));
-            $('#layout').trigger('layout-change');
+
+            if (this.icinga.initialized) {
+                $('#layout').trigger('layout-change');
+            }
+
             // one-column layouts never have any selection active
             $('#col1').removeData('icinga-actiontable-former-href');
             this.icinga.behaviors.actiontable.clearAll();
@@ -330,6 +345,8 @@
             $c.removeData('icingaRefresh');
             $c.removeData('lastUpdate');
             $c.removeData('icingaModule');
+            delete $c[0].dataset.icingaContainerId;
+            $c.removeAttr('class').attr('class', 'container');
             this.icinga.loader.stopPendingRequestsFor($c);
             $c.trigger('close-column');
             $c.html('');
@@ -339,7 +356,10 @@
             if (! this.isOneColLayout()) { return; }
             this.icinga.logger.debug('Switching to double col');
             $('#layout').addClass('twocols');
-            $('#layout').trigger('layout-change');
+
+            if (this.icinga.initialized) {
+                $('#layout').trigger('layout-change');
+            }
         },
 
         prepareColumnFor: function ($el, $target) {
